[SCM] gsequencer/upstream: fixed deprecated devout property renamed to soundcard

jkraehemann-guest at users.alioth.debian.org jkraehemann-guest at users.alioth.debian.org
Sun Jun 14 16:06:56 UTC 2015


The following commit has been merged in the upstream branch:
commit 68bbd5b3a73621afe325c7542b9ad0fcce3bdef5
Author: Joël Krähemann <weedlight at gmail.com>
Date:   Thu Apr 9 16:57:49 2015 +0000

    fixed deprecated devout property renamed to soundcard

diff --git a/src/ags/X/machine/ags_mixer.c b/src/ags/X/machine/ags_mixer.c
index 3333e9f..4c8cb8e 100644
--- a/src/ags/X/machine/ags_mixer.c
+++ b/src/ags/X/machine/ags_mixer.c
@@ -387,7 +387,7 @@ ags_mixer_set_pads(AgsAudio *audio, GType type,
 
 /**
  * ags_mixer_new:
  * @devout: the assigned devout.
  *
  * Creates an #AgsMixer
  *
@@ -396,7 +396,7 @@ ags_mixer_set_pads(AgsAudio *audio, GType type,
  * Since: 0.3
  */
 AgsMixer*
-ags_mixer_new(GObject *devout)
+ags_mixer_new(GObject *soundcard)
 {
   AgsMixer *mixer;
 
@@ -404,7 +404,7 @@ ags_mixer_new(GObject *devout)
 				    NULL);
 
   g_object_set(G_OBJECT(AGS_MACHINE(mixer)->audio),
-	       "devout\0", devout,
+	       "soundcard\0", soundcard,
 	       NULL);
 
   return(mixer);
@@ -387,7 +387,7 @@ ags_mixer_set_pads(AgsAudio *audio, GType type,
 /**
  * ags_mixer_new:
- * @devout: the assigned devout.
+ * @soundcard: the assigned soundcard.
  *
  * Creates an #AgsMixer

-- 
gsequencer packaging



More information about the pkg-multimedia-commits mailing list